@@ -1,10 +1,10 @@
 from typing import Type
 
 from .models.board import Board
-from .card import Card
-from .card_list import CardList
+from .models.card import Card
+from .models.card_list import CardList
 from .constructors import has_board, has_card, has_list
-from .user import User
+from .models.user import User
 
 
 class Trello(User):
